@@ -12,10 +12,10 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-
+from __future__ import annotations
 from collections import ChainMap
 import functools
-from typing import Union, Optional
+from typing import Any, Union, Optional
 from forallpeople.dimensions import Dimensions
 import forallpeople.tuplevector as vec
 
@@ -441,7 +441,6 @@ def swap_scientific_notation_float(value: float, precision: int) -> str:
     elem = 0.1353 with precision=3 will round to 0.135 with three significant digits
     (3 == 3). Therefore this float will not be formatted.
     """
-    print("Swap scinotfloat")
     if test_for_small_float(value, precision):
         new_value = (
                 "{:.{precision}e}".format(value, precision=precision)
@@ -455,10 +454,9 @@ def swap_scientific_notation_float(value: float, precision: int) -> str:
 def test_for_small_float(value: float, precision: int) -> bool:
     """
     Returns True if 'value' is a float whose rounded str representation
-    has fewer significant figures than the numer in 'precision'. 
+    has fewer significant figures than the number in 'precision'. 
     Return False otherwise.
     """
-    print("true")
     if not isinstance(value, (float)):
         return False
     if value == 0:
@@ -468,10 +466,8 @@ def test_for_small_float(value: float, precision: int) -> bool:
         return True
     if "." in value_as_str:
         left, *_right = value_as_str.split(".")
-        print(left)
         if left != "0":
             return False
-    print(round(value, precision), round(value, precision + 1))
     if (
         round(value, precision) != round(value, precision + 1)
         or str(abs(round(value, precision))).replace("0", "").replace(".", "")
@@ -483,27 +479,6 @@ def test_for_small_float(value: float, precision: int) -> bool:
         return False
 
 
-    # if not isinstance(elem, (float)):
-    #     return False
-    # if elem == 0:
-    #     return False
-    # elem_as_str = str(round(abs(elem), precision))
-    # if "e" in str(elem):
-    #     return True
-    # if "." in elem_as_str:
-    #     left, *_right = elem_as_str.split(".")
-    #     if left != "0":
-    #         return False
-    # if (
-    #     round(elem, precision) != round(elem, precision + 1)
-    #     or str(abs(round(elem, precision))).replace("0", "").replace(".", "")
-    #     == str(abs(round(elem, precision + 1))).replace("0", "").replace(".", "")
-    #     == ""
-    # ):
-    #     return True
-    # else:
-    #     return False
-
 def swap_scientific_notation_str(value_as_str: str) -> str:
     """
     Returns a deque representing 'line' with any python 
@@ -511,7 +486,6 @@ def swap_scientific_notation_str(value_as_str: str) -> str:
     that are in scientific notation "e" format converted into a Latex 
     scientific notation.
     """
-    print("swap sci not str")
     b = "}"
     if test_for_scientific_notation_str(value_as_str):
         new_value_as_str = value_as_str.replace("e", " \\times 10 ^ {") + b
@@ -525,7 +499,6 @@ def test_for_scientific_notation_str(value_as_str: str) -> bool:
     e.g. 1.23e-3, 0.09e5
     Returns False otherwise
     """
-    print("sci not str")
     test_for_float = False
     try:
         float(value_as_str)
@@ -535,4 +508,16 @@ def test_for_scientific_notation_str(value_as_str: str) -> bool:
 
     if "e" in str(value_as_str).lower() and test_for_float:
         return True
-    return False
\ No newline at end of file
+    return False
+
+def is_nan(value: Any) -> bool:
+    """
+    Returns True if 'value' is some form of NaN, whether float('nan')
+    or a numpy or pandas Nan.
+    """
+    # Test for numpy.nan and float('nan')
+    if not value == value:
+        return True
+    else:
+        return False
+    
\ No newline at end of file
